@@ -2569,46 +2569,3 @@ class CommentCellFormAdapter(object):
 class FlourishGradebookCommentCell(flourish.form.Form):
 
     fields = field.Fields(ICommentCellForm)
-
-
-class FlourishGradebookCommentCellSubmit(flourish.page.Page):
-
-    def update(self):
-        persons = ISchoolToolApplication(None)['persons']
-        student_id = self.request.get('comment-student-id')
-        student = persons.get(student_id, None)
-
-        gradebook = proxy.removeSecurityProxy(self.context)
-        worksheet = gradebook.context
-        activity_id = self.request.get('comment-activity-id')
-        activity = worksheet.get(activity_id, None)
-
-        value = self.request.get('form.widgets.value', None)
-
-        self.request.response.redirect(absoluteURL(gradebook, self.request))
-        if student is not None and activity is not None and value is not None:
-            evaluator = getName(IPerson(self.request.principal))
-
-            # XXX: heavy code duplication with GradebookOverview
-
-            # If a value is present, create an evaluation, if the
-            # score is different
-            try:
-                request_score_value = activity.scoresystem.fromUnicode(
-                    value)
-            except (ValidationError, ValueError):
-                return
-
-            score = gradebook.getScore(student, activity)
-            # Delete the score
-            if score and request_score_value is UNSCORED:
-                gradebook.removeEvaluation(student, activity,
-                                           evaluator=evaluator)
-            # Do nothing
-            elif not score and request_score_value is UNSCORED:
-                return
-            # Replace the score or add new one
-            elif not score or request_score_value != score.value:
-                gradebook.evaluate(student, activity, request_score_value,
-                                   evaluator)
-
